==> lxqt-panel-0.14.0.tar.xz: lxqt-panel-0.14.0/panel/translations/lxqt-panel_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>AddPluginDialog</name>
    <message>
        <location filename="../config/addplugindialog.ui" line="14"/>
        <source>Add Plugins</source>
        <translation>添加插件</translation>
    </message>
    <message>
        <location filename="../config/addplugindialog.ui" line="22"/>
        <source>Search:</source>
        <translation>搜索:</translation>
    </message>
    <message>
        <location filename="../config/addplugindialog.ui" line="98"/>
        <source>Add Widget</source>
        <translation>添加小部件</translation>
    </message>
    <message>
        <location filename="../config/addplugindialog.ui" line="105"/>
        <source>Close</source>
        <translation>关闭</translation>
    </message>
    <message>
        <location filename="../config/addplugindialog.cpp" line="115"/>
        <source>(only one instance can run at a time)</source>
        <translation>（一次只能运行一个替代项）</translation>
    </message>
</context>
<context>
    <name>ConfigPanelDialog</name>
    <message>
        <location filename="../config/configpaneldialog.cpp" line="31"/>
        <source>Configure Panel</source>
        <translation>配置面板</translation>
    </message>
    <message>
        <location filename="../config/configpaneldialog.cpp" line="38"/>
        <source>Panel</source>
        <translation>面板</translation>
    </message>
    <message>
        <location filename="../config/configpaneldialog.cpp" line="42"/>
        <source>Widgets</source>
        <translation>小部件</translation>
    </message>
</context>
<context>
    <name>ConfigPanelWidget</name>
    <message>
        <location filename="../config/configpanelwidget.ui" line="20"/>
        <source>Configure panel</source>
        <translation>配置面板</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="44"/>
        <source>Size</source>
        <translation>大小</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="81"/>
        <source>Size:</source>
        <translation>大小:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="109"/>
        <location filename="../config/configpanelwidget.ui" line="153"/>
        <source> px</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="166"/>
        <source>Icon size:</source>
        <translation>图标大小:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="88"/>
        <source>Length:</source>
        <translation>长度:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="68"/>
        <source>&lt;p&gt;Negative pixel value sets the panel length to that many pixels less than available screen space.&lt;/p&gt;&lt;p/&gt;&lt;p&gt;&lt;i&gt;E.g. &quot;Length&quot; set to -100px, screen size is 1000px, then real panel length will be 900 px.&lt;/i&gt;&lt;/p&gt;</source>
        <translation>&lt;p&gt;如设置长度为负数，则面板长度会等于最大长度加上输入值&lt;/p&gt;&lt;p/&gt;&lt;p&gt;&lt;i&gt;例：如“长度”设置为-100px，且最大长度为1000px，则实际显示长度为900px。&lt;/i&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="96"/>
        <source>%</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="101"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="202"/>
        <source>Alignment &amp;&amp; position</source>
        <translation>对齐与位置</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="262"/>
        <location filename="../config/configpanelwidget.ui" line="285"/>
        <source>Zero means no animation</source>
        <translation>如设置为0，则不显示动画</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="288"/>
        <location filename="../config/configpanelwidget.ui" line="314"/>
        <source> ms</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="265"/>
        <source>Animation duration:</source>
        <translation>动画时间:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="173"/>
        <source>Rows:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="219"/>
        <location filename="../config/configpanelwidget.cpp" line="206"/>
        <source>Left</source>
        <translation>左</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="224"/>
        <location filename="../config/configpanelwidget.cpp" line="207"/>
        <location filename="../config/configpanelwidget.cpp" line="213"/>
        <source>Center</source>
        <translation>居中</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="229"/>
        <location filename="../config/configpanelwidget.cpp" line="208"/>
        <source>Right</source>
        <translation>右</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="250"/>
        <source>A&amp;uto-hide</source>
        <translation>自动隐藏(&amp;U)</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="301"/>
        <location filename="../config/configpanelwidget.ui" line="311"/>
        <source>Zero means no delay</source>
        <translation>如设置为0，则无延迟</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="304"/>
        <source>Show with delay:</source>
        <translation>动画延迟:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="330"/>
        <source>Don&apos;t allow maximized windows go under the panel window</source>
        <translation>不允许最大化窗口显示在面板窗口之下</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="333"/>
        <source>Reserve space on display</source>
        <translation>显示器上的保留空间</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="349"/>
        <source>Custom styling</source>
        <translation>自定义样式</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="370"/>
        <source>Font color:</source>
        <translation>字体颜色:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="410"/>
        <source>Background color:</source>
        <translation>背景颜色:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="449"/>
        <source>Background opacity:</source>
        <translation>背景不透明度:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="481"/>
        <source>&lt;small&gt;Compositing is required for panel transparency.&lt;/small&gt;</source>
        <translation>&lt;small&gt;必须要启用合成特效才可以使面板透明&lt;/small&gt;</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="509"/>
        <source>Background image:</source>
        <translation>背景图像:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="561"/>
        <source>A partial workaround for widget styles that
cannot give a separate theme to the panel.

You might also want to disable:

LXQt Appearance Configuration →
Icons Theme →
Colorize icons based on widget style (palette)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="571"/>
        <source>Override icon &amp;theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="586"/>
        <source>Icon theme for panels:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="208"/>
        <source>Alignment:</source>
        <translation>对齐:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="237"/>
        <source>Position:</source>
        <translation>位置:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="172"/>
        <source>Top of desktop</source>
        <translation>桌面顶部</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="173"/>
        <source>Left of desktop</source>
        <translation>桌面左侧</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="174"/>
        <source>Right of desktop</source>
        <translation>桌面右侧</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="175"/>
        <source>Bottom of desktop</source>
        <translation>桌面底部</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="184"/>
        <source>Top of desktop %1</source>
        <translation>桌面顶部 %1</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="185"/>
        <source>Left of desktop %1</source>
        <translation>桌面左侧 %1</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="186"/>
        <source>Right of desktop %1</source>
        <translation>左面右侧 %1</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="187"/>
        <source>Bottom of desktop %1</source>
        <translation>桌面底部 %1</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="212"/>
        <source>Top</source>
        <translation>顶部</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="214"/>
        <source>Bottom</source>
        <translation>底部</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="430"/>
        <location filename="../config/configpanelwidget.cpp" line="446"/>
        <source>Pick color</source>
        <translation>选择颜色</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="464"/>
        <source>Images (*.png *.gif *.jpg)</source>
        <translation>图像 (*.png *.gif *.jpg)</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="464"/>
        <source>Pick image</source>
        <translation>选择图像</translation>
    </message>
</context>
<context>
    <name>ConfigPluginsWidget</name>
    <message>
        <location filename="../config/configpluginswidget.ui" line="14"/>
        <source>Configure Plugins</source>
        <translation>配置插件</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="84"/>
        <source>Note: changes made in this page cannot be reset.</source>
        <translation>注：在此页更改的设置无法重置。</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="112"/>
        <source>Move up</source>
        <translation>上移</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="115"/>
        <location filename="../config/configpluginswidget.ui" line="129"/>
        <location filename="../config/configpluginswidget.ui" line="150"/>
        <location filename="../config/configpluginswidget.ui" line="164"/>
        <location filename="../config/configpluginswidget.ui" line="185"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="126"/>
        <source>Move down</source>
        <translation>下移</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="147"/>
        <source>Add</source>
        <translation>添加</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="161"/>
        <source>Remove</source>
        <translation>删除</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="182"/>
        <source>Configure</source>
        <translation>配置</translation>
    </message>
</context>
<context>
    <name>LXQtPanel</name>
    <message>
        <location filename="../lxqtpanel.cpp" line="1068"/>
        <location filename="../lxqtpanel.cpp" line="1094"/>
        <source>Panel</source>
        <translation>面板</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1097"/>
        <source>Configure Panel</source>
        <translation>配置面板</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1102"/>
        <source>Manage Widgets</source>
        <translation>管理小部件</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1108"/>
        <source>Add New Panel</source>
        <translation>新增面板</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1115"/>
        <source>Remove Panel</source>
        <comment>Menu Item</comment>
        <translation>删除面板</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1120"/>
        <source>Lock This Panel</source>
        <translation>锁定此面板</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1273"/>
        <source>Remove Panel</source>
        <comment>Dialog Title</comment>
        <translation>删除面板</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1274"/>
        <source>Removing a panel can not be undone.
Do you want to remove this panel?</source>
        <translation>删除面板不可撤销。
是否确认要删除此面板？</translation>
    </message>
</context>
<context>
    <name>Plugin</name>
    <message>
        <location filename="../plugin.cpp" line="411"/>
        <source>Configure &quot;%1&quot;</source>
        <translation>配置“%1”</translation>
    </message>
    <message>
        <location filename="../plugin.cpp" line="416"/>
        <source>Move &quot;%1&quot;</source>
        <translation>移动“%1”</translation>
    </message>
    <message>
        <location filename="../plugin.cpp" line="424"/>
        <source>Remove &quot;%1&quot;</source>
        <translation>删除“%1”</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../lxqtpanelapplication.cpp" line="95"/>
        <source>Use alternate configuration file.</source>
        <translation>使用另一个配置文件。</translation>
    </message>
    <message>
        <location filename="../lxqtpanelapplication.cpp" line="96"/>
        <source>Configuration file</source>
        <translation>配置文件</translation>
    </message>
</context>
</TS>

==> lxqt-panel_0.14.1.orig.tar.xz: lxqt-panel-0.14.1/panel/translations/lxqt-panel_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>AddPluginDialog</name>
    <message>
        <location filename="../config/addplugindialog.ui" line="14"/>
        <source>Add Plugins</source>
        <translation>添加插件</translation>
    </message>
    <message>
        <location filename="../config/addplugindialog.ui" line="22"/>
        <source>Search:</source>
        <translation>搜索：</translation>
    </message>
    <message>
        <location filename="../config/addplugindialog.ui" line="98"/>
        <source>Add Widget</source>
        <translation>添加小部件</translation>
    </message>
    <message>
        <location filename="../config/addplugindialog.ui" line="105"/>
        <source>Close</source>
        <translation>关闭</translation>
    </message>
    <message>
        <location filename="../config/addplugindialog.cpp" line="115"/>
        <source>(only one instance can run at a time)</source>
        <translation>（一次只能运行一个实例）</translation>
    </message>
</context>
<context>
    <name>ConfigPanelDialog</name>
    <message>
        <location filename="../config/configpaneldialog.cpp" line="31"/>
        <source>Configure Panel</source>
        <translation>配置面板</translation>
    </message>
    <message>
        <location filename="../config/configpaneldialog.cpp" line="38"/>
        <source>Panel</source>
        <translation>面板</translation>
    </message>
    <message>
        <location filename="../config/configpaneldialog.cpp" line="42"/>
        <source>Widgets</source>
        <translation>小部件</translation>
    </message>
</context>
<context>
    <name>ConfigPanelWidget</name>
    <message>
        <location filename="../config/configpanelwidget.ui" line="20"/>
        <source>Configure panel</source>
        <translation>配置面板</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="44"/>
        <source>Size</source>
        <translation>大小</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="81"/>
        <source>Size:</source>
        <translation>大小：</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="109"/>
        <location filename="../config/configpanelwidget.ui" line="153"/>
        <source> px</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="166"/>
        <source>Icon size:</source>
        <translation>图标大小：</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="88"/>
        <source>Length:</source>
        <translation>长度：</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="68"/>
        <source>&lt;p&gt;Negative pixel value sets the panel length to that many pixels less than available screen space.&lt;/p&gt;&lt;p/&gt;&lt;p&gt;&lt;i&gt;E.g. &quot;Length&quot; set to -100px, screen size is 1000px, then real panel length will be 900 px.&lt;/i&gt;&lt;/p&gt;</source>
        <translation>&lt;p&gt;如设置长度为负数，则面板长度会等于最大长度加上输入值&lt;/p&gt;&lt;p/&gt;&lt;p&gt;&lt;i&gt;例：如“长度”设置为-100px，且最大长度为1000px，则实际显示长度为900px。&lt;/i&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="96"/>
        <source>%</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="101"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="202"/>
        <source>Alignment &amp;&amp; position</source>
        <translation>对齐与位置</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="262"/>
        <location filename="../config/configpanelwidget.ui" line="285"/>
        <source>Zero means no animation</source>
        <translation>如设置为0，则不显示动画</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="288"/>
        <location filename="../config/configpanelwidget.ui" line="314"/>
        <source> ms</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="265"/>
        <source>Animation duration:</source>
        <translation>动画时间:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="173"/>
        <source>Rows:</source>
        <translation>列：</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="219"/>
        <location filename="../config/configpanelwidget.cpp" line="206"/>
        <source>Left</source>
        <translation>左</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="224"/>
        <location filename="../config/configpanelwidget.cpp" line="207"/>
        <location filename="../config/configpanelwidget.cpp" line="213"/>
        <source>Center</source>
        <translation>居中</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="229"/>
        <location filename="../config/configpanelwidget.cpp" line="208"/>
        <source>Right</source>
        <translation>右</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="250"/>
        <source>A&amp;uto-hide</source>
        <translation>自动隐藏(&amp;U)</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="301"/>
        <location filename="../config/configpanelwidget.ui" line="311"/>
        <source>Zero means no delay</source>
        <translation>如设置为0，则无延迟</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="304"/>
        <source>Show with delay:</source>
        <translation>动画延迟:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="330"/>
        <source>Don&apos;t allow maximized windows go under the panel window</source>
        <translation>不允许最大化窗口显示在面板窗口之下</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="333"/>
        <source>Reserve space on display</source>
        <translation>显示器上的保留空间</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="349"/>
        <source>Custom styling</source>
        <translation>自定义样式</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="370"/>
        <source>Font color:</source>
        <translation>字体颜色:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="410"/>
        <source>Background color:</source>
        <translation>背景颜色:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="449"/>
        <source>Background opacity:</source>
        <translation>背景不透明度:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="481"/>
        <source>&lt;small&gt;Compositing is required for panel transparency.&lt;/small&gt;</source>
        <translation>&lt;small&gt;必须要启用合成特效才可以使面板透明&lt;/small&gt;</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="509"/>
        <source>Background image:</source>
        <translation>背景图像:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="561"/>
        <source>A partial workaround for widget styles that
cannot give a separate theme to the panel.

You might also want to disable:

LXQt Appearance Configuration →
Icons Theme →
Colorize icons based on widget style (palette)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="571"/>
        <source>Override icon &amp;theme</source>
        <translation>覆盖图标主题(T)</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="586"/>
        <source>Icon theme for panels:</source>
        <translation>面板的图标主题</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="208"/>
        <source>Alignment:</source>
        <translation>对齐：</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="237"/>
        <source>Position:</source>
        <translation>位置：</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="172"/>
        <source>Top of desktop</source>
        <translation>桌面顶部</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="173"/>
        <source>Left of desktop</source>
        <translation>桌面左侧</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="174"/>
        <source>Right of desktop</source>
        <translation>桌面右侧</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="175"/>
        <source>Bottom of desktop</source>
        <translation>桌面底部</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="184"/>
        <source>Top of desktop %1</source>
        <translation>桌面顶部 %1</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="185"/>
        <source>Left of desktop %1</source>
        <translation>桌面左侧 %1</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="186"/>
        <source>Right of desktop %1</source>
        <translation>左面右侧 %1</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="187"/>
        <source>Bottom of desktop %1</source>
        <translation>桌面底部 %1</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="212"/>
        <source>Top</source>
        <translation>顶部</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="214"/>
        <source>Bottom</source>
        <translation>底部</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="430"/>
        <location filename="../config/configpanelwidget.cpp" line="446"/>
        <source>Pick color</source>
        <translation>选择颜色</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="464"/>
        <source>Images (*.png *.gif *.jpg)</source>
        <translation>图像 (*.png *.gif *.jpg)</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="464"/>
        <source>Pick image</source>
        <translation>选择图像</translation>
    </message>
</context>
<context>
    <name>ConfigPluginsWidget</name>
    <message>
        <location filename="../config/configpluginswidget.ui" line="14"/>
        <source>Configure Plugins</source>
        <translation>配置插件</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="84"/>
        <source>Note: changes made in this page cannot be reset.</source>
        <translation>注：此页的改动无法被重置。</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="112"/>
        <source>Move up</source>
        <translation>上移</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="115"/>
        <location filename="../config/configpluginswidget.ui" line="129"/>
        <location filename="../config/configpluginswidget.ui" line="150"/>
        <location filename="../config/configpluginswidget.ui" line="164"/>
        <location filename="../config/configpluginswidget.ui" line="185"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="126"/>
        <source>Move down</source>
        <translation>下移</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="147"/>
        <source>Add</source>
        <translation>添加</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="161"/>
        <source>Remove</source>
        <translation>删除</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="182"/>
        <source>Configure</source>
        <translation>配置</translation>
    </message>
</context>
<context>
    <name>LXQtPanel</name>
    <message>
        <location filename="../lxqtpanel.cpp" line="1068"/>
        <location filename="../lxqtpanel.cpp" line="1094"/>
        <source>Panel</source>
        <translation>面板</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1097"/>
        <source>Configure Panel</source>
        <translation>配置面板</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1102"/>
        <source>Manage Widgets</source>
        <translation>管理小部件</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1108"/>
        <source>Add New Panel</source>
        <translation>新增面板</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1115"/>
        <source>Remove Panel</source>
        <comment>Menu Item</comment>
        <translation>删除面板</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1120"/>
        <source>Lock This Panel</source>
        <translation>锁定此面板</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1273"/>
        <source>Remove Panel</source>
        <comment>Dialog Title</comment>
        <translation>删除面板</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1274"/>
        <source>Removing a panel can not be undone.
Do you want to remove this panel?</source>
        <translation>删除面板不可撤销。
是否确认要删除此面板？</translation>
    </message>
</context>
<context>
    <name>Plugin</name>
    <message>
        <location filename="../plugin.cpp" line="411"/>
        <source>Configure &quot;%1&quot;</source>
        <translation>配置“%1”</translation>
    </message>
    <message>
        <location filename="../plugin.cpp" line="416"/>
        <source>Move &quot;%1&quot;</source>
        <translation>移动“%1”</translation>
    </message>
    <message>
        <location filename="../plugin.cpp" line="424"/>
        <source>Remove &quot;%1&quot;</source>
        <translation>删除“%1”</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../lxqtpanelapplication.cpp" line="95"/>
        <source>Use alternate configuration file.</source>
        <translation>使用另一个配置文件。</translation>
    </message>
    <message>
        <location filename="../lxqtpanelapplication.cpp" line="96"/>
        <source>Configuration file</source>
        <translation>配置文件</translation>
    </message>
</context>
</TS>
